version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/graphs/v4/natl"
capture mkdir "brazrloc/tex/v4/natl"
capture mkdir "brazrloc/graphs/v4/natl/laborstats"
capture mkdir "brazrloc/tex/v4/natl/laborstats"

capture mkdir "brazrloc/graphs/v4/natl-maleprime"
capture mkdir "brazrloc/tex/v4/natl-maleprime"
capture mkdir "brazrloc/graphs/v4/natl-maleprime/laborstats"
capture mkdir "brazrloc/tex/v4/natl-maleprime/laborstats"


capture log close
log using "brazrloc/logs/labocc-stats.log", replace

// RAIS: NATIONAL 1-PERCENT SAMPLE

* NATIONAL PRIME-AGE MALES, ANNUAL LABOR MARKET EXPERIENCE 1986-97

use wid ano identificad emp_em_31_12 fx_etaria sexo caus_desl_tc cbogrp mes_deslig rem_media using "brazrloc/data/wid-draw-workers-natl", clear
drop if sexo==2  // drop female workers
drop if fx_etaria < 4   // drop workers younger than 25 years, but keep obs. of workers older than 64 years for tracking
drop if ano<1986 | ano>1997
drop sexo

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* fillin worker panels
fillin wid ano
drop _fillin

* redefine variables
rename ano year
sort wid year

* labor market experience indicators by year
mat labocctrns_86_98_tbl = J(6,6,.)
matrix colnames labocctrns_86_98_tbl = indsamejob indsameest indsamefrm indothrfrm indretired indunacc
preserve
local yrrow 0
foreach year in 1986 1988 1990 1992 1994 1996 {
  local yrrow = `yrrow' + 1
  matname labocctrns_86_98_tbl `year', rows(`yrrow') explicit
  restore, preserve
  keep if year==`year' | year==`year'+1
  gen int _retires = year if caus_desl_tc==7
  gen int _dies = year if caus_desl_tc==8
  egen int _retiryr = min(_retires), by(wid)
  egen int _deathyr = min(_dies), by(wid)
  drop _retires _dies caus_desl_tc
  // mutually exclusive and exhaustive occupation experience indicators
  * same job (occupation and establishment)
  by wid: gen byte indsamejob = ( year==`year' | (cbogrp==cbogrp[_n-1] & identificad==identificad[_n-1] & year==`year'+1) )
  * different job but same establishment
  by wid: gen byte indsameest = ( indsamejob==0 & identificad~=. & (identificad==identificad[_n-1] & year==`year'+1) )
  * different establishment but same firm
  by wid: gen byte indsamefrm = ( indsamejob==0 & indsameest==0 & identificad~=. & (int(identificad/1000000)==int(identificad[_n-1]/1000000) & year==`year'+1) )
  * different firm
  by wid: gen byte indothrfrm = ( indsamejob==0 & indsameest==0 & indsamefrm==0 & identificad~=. & (int(identificad/1000000)~=int(identificad[_n-1]/1000000) & year==`year'+1) )
  * no employment, but prior retirement or death reported, or worker past retirement age in last observed job
  by wid: gen byte indretired = ( identificad==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 ) ) )
  * unaccounted
  by wid: gen byte indunacc = ( indsamejob==0 & indsameest==0 & indsamefrm==0 & indothrfrm==0 & indretired==0 )
  egen _chk = rsum(ind*)
  qui count if _chk~=1
  if `r(N)'>0  STOP  // indicators not mutually exclusive
  foreach var in indsamejob indsameest indsamefrm indothrfrm indretired indunacc {
    qui summ `var', meanonly
    mat labocctrns_86_98_tbl[`yrrow',colnumb(labocctrns_86_98_tbl,"`var'")]=`r(mean)'
    }
  }
restore
matsave labocctrns_86_98_tbl, p(brazrloc/tex/v4/natl-maleprime/laborstats) replace dropall
gen int year = real(_rowname)
forvalues yr=86/98 {
  local yr1 = `yr' + 1
  replace _rowname = _rowname + "-`yr1'" if _rowname=="19`yr'"
  }
order year

* report
graph bar (mean) indsamejob indsameest indsamefrm indothrfrm, over(_rowname) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed in same job") label(2 "Employed at same plant") label(3 "Employed at same firm") label(4 "Employed at other firm")) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/natl-maleprime/laborstats/labocctrns-86-98.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind*, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl-maleprime/laborstats) name(labocctrns_86_98) fancy replace over nolog
restore


* NATIONAL ANNUAL LABOR MARKET EXPERIENCE 1986-97

use wid ano identificad emp_em_31_12 fx_etaria caus_desl_tc cbogrp mes_deslig rem_media using "brazrloc/data/wid-draw-workers-natl", clear
drop if ano<1986 | ano>1997

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* fillin worker panels
fillin wid ano
drop _fillin

* redefine variables
rename ano year
sort wid year

* labor market experience indicators by year
mat labocctrns_86_98_tbl = J(6,6,.)
matrix colnames labocctrns_86_98_tbl = indsamejob indsameest indsamefrm indothrfrm indretired indunacc
preserve
local yrrow 0
foreach year in 1986 1988 1990 1992 1994 1996 {
  local yrrow = `yrrow' + 1
  matname labocctrns_86_98_tbl `year', rows(`yrrow') explicit
  restore, preserve
  keep if year==`year' | year==`year'+1
  gen int _retires = year if caus_desl_tc==7
  gen int _dies = year if caus_desl_tc==8
  egen int _retiryr = min(_retires), by(wid)
  egen int _deathyr = min(_dies), by(wid)
  drop _retires _dies caus_desl_tc
  // mutually exclusive and exhaustive occupation experience indicators
  * same job (occupation and establishment)
  by wid: gen byte indsamejob = ( year==`year' | (cbogrp==cbogrp[_n-1] & identificad==identificad[_n-1] & year==`year'+1) )
  * different job but same establishment
  by wid: gen byte indsameest = ( indsamejob==0 & identificad~=. & (identificad==identificad[_n-1] & year==`year'+1) )
  * different establishment but same firm
  by wid: gen byte indsamefrm = ( indsamejob==0 & indsameest==0 & identificad~=. & (int(identificad/1000000)==int(identificad[_n-1]/1000000) & year==`year'+1) )
  * different firm
  by wid: gen byte indothrfrm = ( indsamejob==0 & indsameest==0 & indsamefrm==0 & identificad~=. & (int(identificad/1000000)~=int(identificad[_n-1]/1000000) & year==`year'+1) )
  * no employment, but prior retirement or death reported, or worker past retirement age in last observed job
  by wid: gen byte indretired = ( identificad==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 ) ) )
  * unaccounted
  by wid: gen byte indunacc = ( indsamejob==0 & indsameest==0 & indsamefrm==0 & indothrfrm==0 & indretired==0 )
  egen _chk = rsum(ind*)
  qui count if _chk~=1
  if `r(N)'>0  STOP  // indicators not mutually exclusive
  foreach var in indsamejob indsameest indsamefrm indothrfrm indretired indunacc {
    qui summ `var', meanonly
    mat labocctrns_86_98_tbl[`yrrow',colnumb(labocctrns_86_98_tbl,"`var'")]=`r(mean)'
    }
  }
restore
matsave labocctrns_86_98_tbl, p(brazrloc/tex/v4/natl/laborstats) replace dropall
gen int year = real(_rowname)
forvalues yr=86/98 {
  local yr1 = `yr' + 1
  replace _rowname = _rowname + "-`yr1'" if _rowname=="19`yr'"
  }
order year

* report
graph bar (mean) indsamejob indsameest indsamefrm indothrfrm, over(_rowname) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed in same job") label(2 "Employed at same plant") label(3 "Employed at same firm") label(4 "Employed at other firm")) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/natl/laborstats/labocctrns-86-98.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind*, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl/laborstats) name(labocctrns_86_98) fancy replace over nolog
restore


* NATIONAL PRIME-AGE MALES, LABOR MARKET EXPERIENCE 1986-93

use wid ano identificad emp_em_31_12 fx_etaria sexo caus_desl_tc cbogrp mes_deslig rem_media using "brazrloc/data/wid-draw-workers-natl", clear
drop if sexo==2  // drop female workers
drop if fx_etaria < 4   // drop workers younger than 25 years, but keep obs. of workers older than 64 years for tracking
drop if ano<1986 | ano>1993
drop sexo

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* fillin worker panels
fillin wid ano
drop _fillin

* keep only prime-age male workers with employment on Dec 31, 1986
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | cbogrp==. | fx_etaria>7 ) & ano==1986 )  // mark worker 1986 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
rename ano year
sort wid year

* occupation experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive occupation experience indicators
* same job (occupation and establishment)
by wid: gen byte indsamejob = ( year==1986 | (cbogrp==cbogrp[_n-1] & identificad==identificad[_n-1] & year==1987) | (cbogrp==cbogrp[_n-2] & identificad==identificad[_n-2] & year==1988) | (cbogrp==cbogrp[_n-3] & identificad==identificad[_n-3] & year==1989) | (cbogrp==cbogrp[_n-4] & identificad==identificad[_n-4] & year==1990) | (cbogrp==cbogrp[_n-5] & identificad==identificad[_n-5] & year==1991) | (cbogrp==cbogrp[_n-6] & identificad==identificad[_n-6] & year==1992) | (cbogrp==cbogrp[_n-7] & identificad==identificad[_n-7] & year==1993) )
* different job but same establishment
by wid: gen byte indsameest = ( indsamejob==0 & identificad~=. & ( (identificad==identificad[_n-1] & year==1987) | (identificad==identificad[_n-2] & year==1988) | (identificad==identificad[_n-3] & year==1989) | (identificad==identificad[_n-4] & year==1990) | (identificad==identificad[_n-5] & year==1991) | (identificad==identificad[_n-6] & year==1992) | (identificad==identificad[_n-7] & year==1993) ) )
* different establishment but same firm
by wid: gen byte indsamefrm = ( indsamejob==0 & indsameest==0 & identificad~=. & ( (int(identificad/1000000)==int(identificad[_n-1]/1000000) & year==1987) | (int(identificad/1000000)==int(identificad[_n-2]/1000000) & year==1988) | (int(identificad/1000000)==int(identificad[_n-3]/1000000) & year==1989) | (int(identificad/1000000)==int(identificad[_n-4]/1000000) & year==1990) | (int(identificad/1000000)==int(identificad[_n-5]/1000000) & year==1991) | (int(identificad/1000000)==int(identificad[_n-6]/1000000) & year==1992) | (int(identificad/1000000)==int(identificad[_n-7]/1000000) & year==1993) ) )
* different firm
by wid: gen byte indothrfrm = ( indsamejob==0 & indsameest==0 & indsamefrm==0 & identificad~=. & ( (int(identificad/1000000)~=int(identificad[_n-1]/1000000) & year==1987) | (int(identificad/1000000)~=int(identificad[_n-2]/1000000) & year==1988) | (int(identificad/1000000)~=int(identificad[_n-3]/1000000) & year==1989) | (int(identificad/1000000)~=int(identificad[_n-4]/1000000) & year==1990) | (int(identificad/1000000)~=int(identificad[_n-5]/1000000) & year==1991) | (int(identificad/1000000)~=int(identificad[_n-6]/1000000) & year==1992) | (int(identificad/1000000)~=int(identificad[_n-7]/1000000) & year==1993) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( identificad==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamejob==0 & indsameest==0 & indsamefrm==0 & indothrfrm==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive

* report
summ ind*
graph bar (mean) indsamejob indsameest indsamefrm indothrfrm if year>1986, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed in same job") label(2 "Employed at same plant") label(3 "Employed at same firm") label(4 "Employed at other firm") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/natl-maleprime/laborstats/laboccexp-86-93.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1986, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl-maleprime/laborstats) name(laboccexp_86_93) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1986, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl-maleprime/laborstats) name(laboccexp_86_93_sd) fancy replace over nolog
restore


* NATIONAL PRIME-AGE MALES, LABOR MARKET EXPERIENCE 1990-97

use wid ano identificad emp_em_31_12 fx_etaria sexo caus_desl_tc cbogrp mes_deslig rem_media using "brazrloc/data/wid-draw-workers-natl", clear
drop if sexo==2  // drop female workers
drop if fx_etaria < 4   // drop workers younger than 25 years, but keep obs. of workers older than 64 years for tracking
drop if ano<1990 | ano>1997
drop sexo

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* fillin worker panels
fillin wid ano
drop _fillin

* keep only prime-age male workers with employment on Dec 31, 1990
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | cbogrp==. | fx_etaria>7 ) & ano==1990 )  // mark worker 1990 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
rename ano year
sort wid year

* occupation experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive occupation experience indicators
* same job (occupation and establishment)
by wid: gen byte indsamejob = ( year==1990 | (cbogrp==cbogrp[_n-1] & identificad==identificad[_n-1] & year==1991) | (cbogrp==cbogrp[_n-2] & identificad==identificad[_n-2] & year==1992) | (cbogrp==cbogrp[_n-3] & identificad==identificad[_n-3] & year==1993) | (cbogrp==cbogrp[_n-4] & identificad==identificad[_n-4] & year==1994) | (cbogrp==cbogrp[_n-5] & identificad==identificad[_n-5] & year==1995) | (cbogrp==cbogrp[_n-6] & identificad==identificad[_n-6] & year==1996) | (cbogrp==cbogrp[_n-7] & identificad==identificad[_n-7] & year==1997) )
* different job but same establishment
by wid: gen byte indsameest = ( indsamejob==0 & identificad~=. & ( (identificad==identificad[_n-1] & year==1991) | (identificad==identificad[_n-2] & year==1992) | (identificad==identificad[_n-3] & year==1993) | (identificad==identificad[_n-4] & year==1994) | (identificad==identificad[_n-5] & year==1995) | (identificad==identificad[_n-6] & year==1996) | (identificad==identificad[_n-7] & year==1997) ) )
* different establishment but same firm
by wid: gen byte indsamefrm = ( indsamejob==0 & indsameest==0 & identificad~=. & ( (int(identificad/1000000)==int(identificad[_n-1]/1000000) & year==1991) | (int(identificad/1000000)==int(identificad[_n-2]/1000000) & year==1992) | (int(identificad/1000000)==int(identificad[_n-3]/1000000) & year==1993) | (int(identificad/1000000)==int(identificad[_n-4]/1000000) & year==1994) | (int(identificad/1000000)==int(identificad[_n-5]/1000000) & year==1995) | (int(identificad/1000000)==int(identificad[_n-6]/1000000) & year==1996) | (int(identificad/1000000)==int(identificad[_n-7]/1000000) & year==1997) ) )
* different firm
by wid: gen byte indothrfrm = ( indsamejob==0 & indsameest==0 & indsamefrm==0 & identificad~=. & ( (int(identificad/1000000)~=int(identificad[_n-1]/1000000) & year==1991) | (int(identificad/1000000)~=int(identificad[_n-2]/1000000) & year==1992) | (int(identificad/1000000)~=int(identificad[_n-3]/1000000) & year==1993) | (int(identificad/1000000)~=int(identificad[_n-4]/1000000) & year==1994) | (int(identificad/1000000)~=int(identificad[_n-5]/1000000) & year==1995) | (int(identificad/1000000)~=int(identificad[_n-6]/1000000) & year==1996) | (int(identificad/1000000)~=int(identificad[_n-7]/1000000) & year==1997) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( identificad==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamejob==0 & indsameest==0 & indsamefrm==0 & indothrfrm==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive

* report
summ ind*
graph bar (mean) indsamejob indsameest indsamefrm indothrfrm if year>1990, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed in same job") label(2 "Employed at same plant") label(3 "Employed at same firm") label(4 "Employed at other firm") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/natl-maleprime/laborstats/laboccexp-90-97.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1990, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl-maleprime/laborstats) name(laboccexp_90_97) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1990, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl-maleprime/laborstats) name(laboccexp_90_97_sd) fancy replace over nolog
restore


* NATIONAL PRIME-AGE MALES, LABOR MARKET EXPERIENCE 1994-2001

use wid ano identificad emp_em_31_12 fx_etaria sexo caus_desl_tc cbogrp mes_deslig rem_media using "brazrloc/data/wid-draw-workers-natl", clear
drop if sexo==2  // drop female workers
drop if fx_etaria < 4   // drop workers younger than 25 years, but keep obs. of workers older than 64 years for tracking
drop if ano<1994 | ano>2001
drop sexo

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* fillin worker panels
fillin wid ano
drop _fillin

* keep only prime-age male workers with employment on Dec 31, 1994
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | cbogrp==. | fx_etaria>7 ) & ano==1994 )  // mark worker 1994 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
rename ano year
sort wid year

* occupation experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive occupation experience indicators
* same job (occupation and establishment)
by wid: gen byte indsamejob = ( year==1994 | (cbogrp==cbogrp[_n-1] & identificad==identificad[_n-1] & year==1995) | (cbogrp==cbogrp[_n-2] & identificad==identificad[_n-2] & year==1996) | (cbogrp==cbogrp[_n-3] & identificad==identificad[_n-3] & year==1997) | (cbogrp==cbogrp[_n-4] & identificad==identificad[_n-4] & year==1998) | (cbogrp==cbogrp[_n-5] & identificad==identificad[_n-5] & year==1999) | (cbogrp==cbogrp[_n-6] & identificad==identificad[_n-6] & year==2000) | (cbogrp==cbogrp[_n-7] & identificad==identificad[_n-7] & year==2001) )
* different job but same establishment
by wid: gen byte indsameest = ( indsamejob==0 & identificad~=. & ( (identificad==identificad[_n-1] & year==1995) | (identificad==identificad[_n-2] & year==1996) | (identificad==identificad[_n-3] & year==1997) | (identificad==identificad[_n-4] & year==1998) | (identificad==identificad[_n-5] & year==1999) | (identificad==identificad[_n-6] & year==2000) | (identificad==identificad[_n-7] & year==2001) ) )
* different establishment but same firm
by wid: gen byte indsamefrm = ( indsamejob==0 & indsameest==0 & identificad~=. & ( (int(identificad/1000000)==int(identificad[_n-1]/1000000) & year==1995) | (int(identificad/1000000)==int(identificad[_n-2]/1000000) & year==1996) | (int(identificad/1000000)==int(identificad[_n-3]/1000000) & year==1997) | (int(identificad/1000000)==int(identificad[_n-4]/1000000) & year==1998) | (int(identificad/1000000)==int(identificad[_n-5]/1000000) & year==1999) | (int(identificad/1000000)==int(identificad[_n-6]/1000000) & year==2000) | (int(identificad/1000000)==int(identificad[_n-7]/1000000) & year==2001) ) )
* different firm
by wid: gen byte indothrfrm = ( indsamejob==0 & indsameest==0 & indsamefrm==0 & identificad~=. & ( (int(identificad/1000000)~=int(identificad[_n-1]/1000000) & year==1995) | (int(identificad/1000000)~=int(identificad[_n-2]/1000000) & year==1996) | (int(identificad/1000000)~=int(identificad[_n-3]/1000000) & year==1997) | (int(identificad/1000000)~=int(identificad[_n-4]/1000000) & year==1998) | (int(identificad/1000000)~=int(identificad[_n-5]/1000000) & year==1999) | (int(identificad/1000000)~=int(identificad[_n-6]/1000000) & year==2000) | (int(identificad/1000000)~=int(identificad[_n-7]/1000000) & year==2001) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( identificad==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamejob==0 & indsameest==0 & indsamefrm==0 & indothrfrm==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive

* report
summ ind*
graph bar (mean) indsamejob indsameest indsamefrm indothrfrm if year>1994, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed in same job") label(2 "Employed at same plant") label(3 "Employed at same firm") label(4 "Employed at other firm") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/natl-maleprime/laborstats/laboccexp-94-01.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1994, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl-maleprime/laborstats) name(laboccexp_94_01) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1994, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl-maleprime/laborstats) name(laboccexp_94_01_sd) fancy replace over nolog
restore


* NATIONAL LABOR MARKET EXPERIENCE 1986-93

use wid ano identificad emp_em_31_12 fx_etaria caus_desl_tc cbogrp mes_deslig rem_media using "brazrloc/data/wid-draw-workers-natl", clear
drop if ano<1986 | ano>1993

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* fillin worker panels
fillin wid ano
drop _fillin

* keep only prime-age male workers with employment on Dec 31, 1986
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | cbogrp==. | fx_etaria>7 ) & ano==1986 )  // mark worker 1986 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
rename ano year
sort wid year

* occupation experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive occupation experience indicators
* same job (occupation and establishment)
by wid: gen byte indsamejob = ( year==1986 | (cbogrp==cbogrp[_n-1] & identificad==identificad[_n-1] & year==1987) | (cbogrp==cbogrp[_n-2] & identificad==identificad[_n-2] & year==1988) | (cbogrp==cbogrp[_n-3] & identificad==identificad[_n-3] & year==1989) | (cbogrp==cbogrp[_n-4] & identificad==identificad[_n-4] & year==1990) | (cbogrp==cbogrp[_n-5] & identificad==identificad[_n-5] & year==1991) | (cbogrp==cbogrp[_n-6] & identificad==identificad[_n-6] & year==1992) | (cbogrp==cbogrp[_n-7] & identificad==identificad[_n-7] & year==1993) )
* different job but same establishment
by wid: gen byte indsameest = ( indsamejob==0 & identificad~=. & ( (identificad==identificad[_n-1] & year==1987) | (identificad==identificad[_n-2] & year==1988) | (identificad==identificad[_n-3] & year==1989) | (identificad==identificad[_n-4] & year==1990) | (identificad==identificad[_n-5] & year==1991) | (identificad==identificad[_n-6] & year==1992) | (identificad==identificad[_n-7] & year==1993) ) )
* different establishment but same firm
by wid: gen byte indsamefrm = ( indsamejob==0 & indsameest==0 & identificad~=. & ( (int(identificad/1000000)==int(identificad[_n-1]/1000000) & year==1987) | (int(identificad/1000000)==int(identificad[_n-2]/1000000) & year==1988) | (int(identificad/1000000)==int(identificad[_n-3]/1000000) & year==1989) | (int(identificad/1000000)==int(identificad[_n-4]/1000000) & year==1990) | (int(identificad/1000000)==int(identificad[_n-5]/1000000) & year==1991) | (int(identificad/1000000)==int(identificad[_n-6]/1000000) & year==1992) | (int(identificad/1000000)==int(identificad[_n-7]/1000000) & year==1993) ) )
* different firm
by wid: gen byte indothrfrm = ( indsamejob==0 & indsameest==0 & indsamefrm==0 & identificad~=. & ( (int(identificad/1000000)~=int(identificad[_n-1]/1000000) & year==1987) | (int(identificad/1000000)~=int(identificad[_n-2]/1000000) & year==1988) | (int(identificad/1000000)~=int(identificad[_n-3]/1000000) & year==1989) | (int(identificad/1000000)~=int(identificad[_n-4]/1000000) & year==1990) | (int(identificad/1000000)~=int(identificad[_n-5]/1000000) & year==1991) | (int(identificad/1000000)~=int(identificad[_n-6]/1000000) & year==1992) | (int(identificad/1000000)~=int(identificad[_n-7]/1000000) & year==1993) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( identificad==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamejob==0 & indsameest==0 & indsamefrm==0 & indothrfrm==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive

* report
summ ind*
graph bar (mean) indsamejob indsameest indsamefrm indothrfrm if year>1986, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed in same job") label(2 "Employed at same plant") label(3 "Employed at same firm") label(4 "Employed at other firm") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/natl/laborstats/laboccexp-86-93.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1986, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl/laborstats) name(laboccexp_86_93) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1986, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl/laborstats) name(laboccexp_86_93_sd) fancy replace over nolog
restore


* NATIONAL LABOR MARKET EXPERIENCE 1990-97

use wid ano identificad emp_em_31_12 fx_etaria caus_desl_tc cbogrp mes_deslig rem_media using "brazrloc/data/wid-draw-workers-natl", clear
drop if ano<1990 | ano>1997

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* fillin worker panels
fillin wid ano
drop _fillin

* keep only prime-age male workers with employment on Dec 31, 1990
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | cbogrp==. | fx_etaria>7 ) & ano==1990 )  // mark worker 1990 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
rename ano year
sort wid year

* occupation experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive occupation experience indicators
* same job (occupation and establishment)
by wid: gen byte indsamejob = ( year==1990 | (cbogrp==cbogrp[_n-1] & identificad==identificad[_n-1] & year==1991) | (cbogrp==cbogrp[_n-2] & identificad==identificad[_n-2] & year==1992) | (cbogrp==cbogrp[_n-3] & identificad==identificad[_n-3] & year==1993) | (cbogrp==cbogrp[_n-4] & identificad==identificad[_n-4] & year==1994) | (cbogrp==cbogrp[_n-5] & identificad==identificad[_n-5] & year==1995) | (cbogrp==cbogrp[_n-6] & identificad==identificad[_n-6] & year==1996) | (cbogrp==cbogrp[_n-7] & identificad==identificad[_n-7] & year==1997) )
* different job but same establishment
by wid: gen byte indsameest = ( indsamejob==0 & identificad~=. & ( (identificad==identificad[_n-1] & year==1991) | (identificad==identificad[_n-2] & year==1992) | (identificad==identificad[_n-3] & year==1993) | (identificad==identificad[_n-4] & year==1994) | (identificad==identificad[_n-5] & year==1995) | (identificad==identificad[_n-6] & year==1996) | (identificad==identificad[_n-7] & year==1997) ) )
* different establishment but same firm
by wid: gen byte indsamefrm = ( indsamejob==0 & indsameest==0 & identificad~=. & ( (int(identificad/1000000)==int(identificad[_n-1]/1000000) & year==1991) | (int(identificad/1000000)==int(identificad[_n-2]/1000000) & year==1992) | (int(identificad/1000000)==int(identificad[_n-3]/1000000) & year==1993) | (int(identificad/1000000)==int(identificad[_n-4]/1000000) & year==1994) | (int(identificad/1000000)==int(identificad[_n-5]/1000000) & year==1995) | (int(identificad/1000000)==int(identificad[_n-6]/1000000) & year==1996) | (int(identificad/1000000)==int(identificad[_n-7]/1000000) & year==1997) ) )
* different firm
by wid: gen byte indothrfrm = ( indsamejob==0 & indsameest==0 & indsamefrm==0 & identificad~=. & ( (int(identificad/1000000)~=int(identificad[_n-1]/1000000) & year==1991) | (int(identificad/1000000)~=int(identificad[_n-2]/1000000) & year==1992) | (int(identificad/1000000)~=int(identificad[_n-3]/1000000) & year==1993) | (int(identificad/1000000)~=int(identificad[_n-4]/1000000) & year==1994) | (int(identificad/1000000)~=int(identificad[_n-5]/1000000) & year==1995) | (int(identificad/1000000)~=int(identificad[_n-6]/1000000) & year==1996) | (int(identificad/1000000)~=int(identificad[_n-7]/1000000) & year==1997) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( identificad==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamejob==0 & indsameest==0 & indsamefrm==0 & indothrfrm==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive

* report
summ ind*
graph bar (mean) indsamejob indsameest indsamefrm indothrfrm if year>1990, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed in same job") label(2 "Employed at same plant") label(3 "Employed at same firm") label(4 "Employed at other firm") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/natl/laborstats/laboccexp-90-97.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1990, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl/laborstats) name(laboccexp_90_97) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1990, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl/laborstats) name(laboccexp_90_97_sd) fancy replace over nolog
restore


* NATIONAL LABOR MARKET EXPERIENCE 1994-2001

use wid ano identificad emp_em_31_12 fx_etaria caus_desl_tc cbogrp mes_deslig rem_media using "brazrloc/data/wid-draw-workers-natl", clear
drop if ano<1994 | ano>2001

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* keep last employment per year
egen _lastjob = max(mes_deslig), by(wid ano)
keep if mes_deslig==_lastjob
drop _lastjob mes_deslig

* if more than one last job per year, keep job with highest pay (random drop for pay ties)
sort wid ano rem_media
by wid ano: keep if _n==_N
drop rem_media

* fillin worker panels
fillin wid ano
drop _fillin

* keep only prime-age male workers with employment on Dec 31, 1994
gen byte _mark = ( (identificad==. | emp_em_31_12~=1 | cbogrp==. | fx_etaria>7 ) & ano==1994 )  // mark worker 1994 for deletion
egen byte _todel = max(_mark), by(wid)  // spread mark to delete worker panel
sort wid ano
drop if _todel
drop emp_em_31_12 _mark _todel

* redefine variables
rename ano year
sort wid year

* occupation experience indicators
gen int _retires = year if caus_desl_tc==7
gen int _dies = year if caus_desl_tc==8
egen int _retiryr = min(_retires), by(wid)
egen int _deathyr = min(_dies), by(wid)
drop _retires _dies caus_desl_tc
// mutually exclusive and exhaustive occupation experience indicators
* same job (occupation and establishment)
by wid: gen byte indsamejob = ( year==1994 | (cbogrp==cbogrp[_n-1] & identificad==identificad[_n-1] & year==1995) | (cbogrp==cbogrp[_n-2] & identificad==identificad[_n-2] & year==1996) | (cbogrp==cbogrp[_n-3] & identificad==identificad[_n-3] & year==1997) | (cbogrp==cbogrp[_n-4] & identificad==identificad[_n-4] & year==1998) | (cbogrp==cbogrp[_n-5] & identificad==identificad[_n-5] & year==1999) | (cbogrp==cbogrp[_n-6] & identificad==identificad[_n-6] & year==2000) | (cbogrp==cbogrp[_n-7] & identificad==identificad[_n-7] & year==2001) )
* different job but same establishment
by wid: gen byte indsameest = ( indsamejob==0 & identificad~=. & ( (identificad==identificad[_n-1] & year==1995) | (identificad==identificad[_n-2] & year==1996) | (identificad==identificad[_n-3] & year==1997) | (identificad==identificad[_n-4] & year==1998) | (identificad==identificad[_n-5] & year==1999) | (identificad==identificad[_n-6] & year==2000) | (identificad==identificad[_n-7] & year==2001) ) )
* different establishment but same firm
by wid: gen byte indsamefrm = ( indsamejob==0 & indsameest==0 & identificad~=. & ( (int(identificad/1000000)==int(identificad[_n-1]/1000000) & year==1995) | (int(identificad/1000000)==int(identificad[_n-2]/1000000) & year==1996) | (int(identificad/1000000)==int(identificad[_n-3]/1000000) & year==1997) | (int(identificad/1000000)==int(identificad[_n-4]/1000000) & year==1998) | (int(identificad/1000000)==int(identificad[_n-5]/1000000) & year==1999) | (int(identificad/1000000)==int(identificad[_n-6]/1000000) & year==2000) | (int(identificad/1000000)==int(identificad[_n-7]/1000000) & year==2001) ) )
* different firm
by wid: gen byte indothrfrm = ( indsamejob==0 & indsameest==0 & indsamefrm==0 & identificad~=. & ( (int(identificad/1000000)~=int(identificad[_n-1]/1000000) & year==1995) | (int(identificad/1000000)~=int(identificad[_n-2]/1000000) & year==1996) | (int(identificad/1000000)~=int(identificad[_n-3]/1000000) & year==1997) | (int(identificad/1000000)~=int(identificad[_n-4]/1000000) & year==1998) | (int(identificad/1000000)~=int(identificad[_n-5]/1000000) & year==1999) | (int(identificad/1000000)~=int(identificad[_n-6]/1000000) & year==2000) | (int(identificad/1000000)~=int(identificad[_n-7]/1000000) & year==2001) ) )
* no employment, but prior retirement or death reported, or worker past retirement age in last observed job
by wid: gen byte indretired = ( identificad==. & ( ( year>_retiryr & _retiryr~=. ) | ( year>_deathyr & _deathyr~=. ) | ( fx_etaria[_n-1]==8 | fx_etaria[_n-2]==8 | fx_etaria[_n-3]==8 | fx_etaria[_n-4]==8 | fx_etaria[_n-5]==8 | fx_etaria[_n-6]==8 | fx_etaria[_n-7]==8 ) ) )
* unaccounted
by wid: gen byte indunacc = ( indsamejob==0 & indsameest==0 & indsamefrm==0 & indothrfrm==0 & indretired==0 )
egen _chk = rsum(ind*)
qui count if _chk~=1
if `r(N)'>0  STOP  // indicators not mutually exclusive

* report
summ ind*
graph bar (mean) indsamejob indsameest indsamefrm indothrfrm if year>1994, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Employed in same job") label(2 "Employed at same plant") label(3 "Employed at same firm") label(4 "Employed at other firm") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/natl/laborstats/laboccexp-94-01.eps", replace
gen byte _dummy = 1
preserve
tabl2tex ind* if year>1994, type(mean) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl/laborstats) name(laboccexp_94_01) fancy replace over nolog
*restore, preserve
*tabl2tex ind* if year>1994, type(sd) r(_dummy) c(year) categ(ind) p(brazrloc/tex/v4/natl/laborstats) name(laboccexp_94_01_sd) fancy replace over nolog
restore

log close
