version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/tex/v4/labor"

capture log close
log using "brazrloc/logs/laborstat-tables.log", replace


// TABLES FOR 1990-1997 //

// Sample Employment Allocation By Sector
matload form_metromale_prime_tbl, dropall p(brazrloc/tex/v4/metromale-prime/laborstats) over
mat rename form_metromale_prime_tbl form_metromale_prime_97_tbl
matrix roweq form_metromale_prime_97_tbl = form_metromale_prime
matload formemplshare_86_98_tbl, dropall p(brazrloc/tex/v4/pme) over
matrix formemplshare_86_98_tbl = formemplshare_86_98_tbl '
matorder formemplshare_86_98_tbl, m(formemplshare_86_98_tbl) ifc(agriculture mining manufacturing retail services other) over
matorder formemplshare_86_98_tbl, m(formemplshare_86_98_tbl) ifr(frmemplsh__1990 frmemplsh__1996) over
matrix rownames formemplshare_86_98_tbl = 1990 1996
matrix roweq formemplshare_86_98_tbl = form_pme
mat formemplshare_86_98_tbl = formemplshare_86_98_tbl , J(2,1,.)
matload form_metromale_tbl, dropall p(brazrloc/tex/v4/metromale/laborstats) over
mat rename form_metromale_tbl form_metromale_97_tbl
matrix roweq form_metromale_97_tbl = form_metromale
matload form_metromale_sp_tbl, dropall p(brazrloc/tex/v4/metromale/laborstats) over
mat rename form_metromale_sp_tbl form_metromale_sp_97_tbl
matrix roweq form_metromale_sp_97_tbl = form_metromale_sp
matload form_natl_tbl, dropall p(brazrloc/tex/v4/natl/laborstats) over
mat rename form_natl_tbl form_natl_97_tbl
matrix roweq form_natl_97_tbl = form_natl
matload form_natl_maleprime_tbl, dropall p(brazrloc/tex/v4/natl-maleprime/laborstats) over
mat rename form_natl_maleprime_tbl form_natl_maleprime_97_tbl
matrix roweq form_natl_maleprime_97_tbl = form_natl_maleprime
matload form_sp_tbl, dropall p(brazrloc/tex/v4/natl/laborstats) over
mat rename form_sp_tbl form_sp_97_tbl
matrix roweq form_sp_97_tbl = form_sp
matload form_pop_tbl, dropall p(brazrloc/tex/v4/natl/laborstats) over
mat rename form_pop_tbl form_pop_97_tbl
matrix roweq form_pop_97_tbl = form_pop
mat form97_tbl = form_metromale_prime_97_tbl \ formemplshare_86_98_tbl \ form_natl_maleprime_97_tbl \ form_metromale_97_tbl \ form_metromale_sp_97_tbl \ form_natl_97_tbl \ form_pop_97_tbl
est2tex form97, replace dropall preserve ready p(brazrloc/tex/v4/labor) fancy digits(3)
mat drop form_metromale_prime_97_tbl formemplshare_86_98_tbl form_natl_maleprime_97_tbl form_metromale_97_tbl form_metromale_sp_97_tbl form_natl_97_tbl form_pop_97_tbl form_sp_97_tbl form97_tbl

// Employment Allocation By Sector and Formality Status
matload form_metromale_prime_tbl, dropall p(brazrloc/tex/v4/metromale-prime/laborstats) over
mat rename form_metromale_prime_tbl form_metromale_prime_97_tbl
matrix roweq form_metromale_prime_97_tbl = form_metromale_prime_97
matload tabelas, dropall p(brazrloc/tex/v4/pme) over rowname(year)
mat formshare = J(8,6,.)
foreach yr in 90 96 {
  local cnstrsh`yr' = tabelas[rownumb(tabelas,"19`yr'"),colnumb(tabelas,"workers_in_construction")] / ( tabelas[rownumb(tabelas,"19`yr'"),colnumb(tabelas,"workers_in_construction")] + tabelas[rownumb(tabelas,"19`yr'"),colnumb(tabelas,"workers_in_public_adm")] ) 
  }
mat _informothr = ( tabelas["1990","share_of_informal_in_construct"]*`cnstrsh90' + tabelas["1990","share_of_informal_in_public_adm"]*(1-`cnstrsh90') ) \\ ( tabelas["1996","share_of_informal_in_construct"]*`cnstrsh96' + tabelas["1996","share_of_informal_in_public_adm"]*(1-`cnstrsh96') )
mat inform_tbl = ( ( tabelas["1990","share_of_informal_in_agriculture"] \\ tabelas["1996","share_of_informal_in_agriculture"] ) , ( tabelas["1990","share_of_informal_in_manufactur"] \\ tabelas["1996","share_of_informal_in_manufactur"] ) , ( tabelas["1990","share_of_informal_in_retail"] \\ tabelas["1996","share_of_informal_in_retail"] ) , ( tabelas["1990","share_of_informal_in_services"] \\ tabelas["1996","share_of_informal_in_services"] ) , _informothr , J(2,1,.) ) / 100
mat drop _informothr
matname inform_tbl inform_pme:1990 inform_pme:1996, rows(1..2) explicit
mat _agg2cols = ( J(1,1,1) , J(1,5,0)) \\ I(6)  // adds first two columns when post-multiplied
mat form_tbl = form_metromale_prime_97_tbl * _agg2cols
mat drop _agg2cols
local oldnames : colfullnames form_metromale_prime_97_tbl
local newnames "primar"  // labels new first column
forvalues i = 3/7 {
  local tmpname : word `i' of `oldnames'
  local newnames "`newnames' `tmpname'"
  }
matname form_tbl `newnames', columns(1..6) explicit
mat forminform97_tbl = form_tbl \ inform_tbl
est2tex forminform97, replace dropall preserve ready p(brazrloc/tex/v4/labor) fancy digits(3)
mat drop form_tbl inform_tbl tabelas formshare form_metromale_prime_97_tbl forminform97_tbl


// TABLES FOR 1990-1998 //

// Sample Employment Allocation By Sector
matload form_metromale_prime_98_tbl, dropall p(brazrloc/tex/v4/metromale-prime/laborstats) over
matrix roweq form_metromale_prime_98_tbl = form_metromale_prime
matload formemplshare_86_98_tbl, dropall p(brazrloc/tex/v4/pme) over
matrix formemplshare_86_98_tbl = formemplshare_86_98_tbl '
matorder formemplshare_86_98_tbl, m(formemplshare_86_98_tbl) ifc(agriculture mining manufacturing retail services other) over
matorder formemplshare_86_98_tbl, m(formemplshare_86_98_tbl) ifr(frmemplsh__1990 frmemplsh__1998) over
matrix rownames formemplshare_86_98_tbl = 1990 1998
matrix roweq formemplshare_86_98_tbl = form_pme
mat formemplshare_86_98_tbl = formemplshare_86_98_tbl , J(2,1,.)
matload form_metromale_98_tbl, dropall p(brazrloc/tex/v4/metromale/laborstats) over
matrix roweq form_metromale_98_tbl = form_metromale
matload form_metromale_sp_98_tbl, dropall p(brazrloc/tex/v4/metromale/laborstats) over
matrix roweq form_metromale_sp_98_tbl = form_metromale_sp
matload form_natl_98_tbl, dropall p(brazrloc/tex/v4/natl/laborstats) over
matrix roweq form_natl_98_tbl = form_natl
matload form_natl_maleprime_98_tbl, dropall p(brazrloc/tex/v4/natl-maleprime/laborstats) over
matrix roweq form_natl_maleprime_98_tbl = form_natl_maleprime
matload form_sp_98_tbl, dropall p(brazrloc/tex/v4/natl/laborstats) over
matrix roweq form_sp_98_tbl = form_sp
matload form_pop_98_tbl, dropall p(brazrloc/tex/v4/natl/laborstats) over
matrix roweq form_pop_98_tbl = form_pop
mat form_tbl = form_metromale_prime_98_tbl \ formemplshare_86_98_tbl \ form_natl_maleprime_98_tbl \ form_metromale_98_tbl \ form_metromale_sp_98_tbl \ form_natl_98_tbl \ form_pop_98_tbl
est2tex form, replace dropall preserve ready p(brazrloc/tex/v4/labor) fancy digits(3)

// Employment Allocation By Sector and Formality Status
matload form_metromale_prime_98_tbl, dropall p(brazrloc/tex/v4/metromale-prime/laborstats) over
matrix roweq form_metromale_prime_98_tbl = form_metromale_prime_98
matload tabelas, dropall p(brazrloc/tex/v4/pme) over rowname(year)
mat formshare = J(8,6,.)
foreach yr in 90 98 {
  local cnstrsh`yr' = tabelas[rownumb(tabelas,"19`yr'"),colnumb(tabelas,"workers_in_construction")] / ( tabelas[rownumb(tabelas,"19`yr'"),colnumb(tabelas,"workers_in_construction")] + tabelas[rownumb(tabelas,"19`yr'"),colnumb(tabelas,"workers_in_public_adm")] ) 
  }
mat _informothr = ( tabelas["1990","share_of_informal_in_construct"]*`cnstrsh90' + tabelas["1990","share_of_informal_in_public_adm"]*(1-`cnstrsh90') ) \\ ( tabelas["1998","share_of_informal_in_construct"]*`cnstrsh98' + tabelas["1998","share_of_informal_in_public_adm"]*(1-`cnstrsh98') )
mat inform_tbl = ( ( tabelas["1990","share_of_informal_in_agriculture"] \\ tabelas["1998","share_of_informal_in_agriculture"] ) , ( tabelas["1990","share_of_informal_in_manufactur"] \\ tabelas["1998","share_of_informal_in_manufactur"] ) , ( tabelas["1990","share_of_informal_in_retail"] \\ tabelas["1998","share_of_informal_in_retail"] ) , ( tabelas["1990","share_of_informal_in_services"] \\ tabelas["1998","share_of_informal_in_services"] ) , _informothr , J(2,1,.) ) / 100
mat drop _informothr
matname inform_tbl inform_pme:1990 inform_pme:1998, rows(1..2) explicit
mat _agg2cols = ( J(1,1,1) , J(1,5,0)) \\ I(6)  // adds first two columns when post-multiplied
mat form_tbl = form_metromale_prime_98_tbl * _agg2cols
mat drop _agg2cols
local oldnames : colfullnames form_metromale_prime_98_tbl
local newnames "primar"  // labels new first column
forvalues i = 3/7 {
  local tmpname : word `i' of `oldnames'
  local newnames "`newnames' `tmpname'"
  }
matname form_tbl `newnames', columns(1..6) explicit
mat forminform_tbl = form_tbl \ inform_tbl
est2tex forminform, replace dropall preserve ready p(brazrloc/tex/v4/labor) fancy digits(3)


// TABLES FOR 1990-2001 //

// Employment by Sector and Firm's Export Status
matload expsec_empl_col_tbl, dropall p(brazrloc/tex/v4/metromale-prime/trans) over
mat rename expsec_empl_col_tbl expsec_metromale
matrix roweq expsec_metromale = metromale
matload expsec_empl_col_tbl, dropall p(brazrloc/tex/v4/natl-maleprime/trans) over
mat rename expsec_empl_col_tbl expsec_natlmalprim
matrix roweq expsec_natlmalprim = natlmalprim
matload expsec_empl_col_tbl, dropall p(brazrloc/tex/v4/natl/trans) over
mat rename expsec_empl_col_tbl expsec_natl
matrix roweq expsec_natl = natl
mat expsec_tbl = expsec_metromale \ expsec_natlmalprim \ expsec_natl
est2tex expsec, replace dropall preserve ready p(brazrloc/tex/v4/labor) fancy digits(3)

// Transitions by Sector and Firm's Export Status
foreach sampl in "metromale-prime" "natl-maleprime" "natl" {
  foreach mat in xtcs_indexp_num xtcs_indexp_num_insec xts_indexp_num xts_indexp_insec_num xts_indexp_num_90_91 xts_indexp_num_96_97 {
    matload `mat'_tbl, dropall p(brazrloc/tex/v4/`sampl'/trans) over
    local name = subinstr(subinstr("`mat'","_indexp_num","",.),"xt","",.)
    matrix roweq `mat'_tbl = `name'
    matrix coleq `mat'_tbl = `name'
    }
  * Table 1990-2001. UL: xtcs_indexp_num, UR: xtcs_indexp_num_insec, LL: xts_indexp_num, LR: xts_indexp_insec_num
  mat xt_indexp_tbl = ( xtcs_indexp_num_tbl , xts_indexp_num_tbl ) \ ( xtcs_indexp_num_insec_tbl , xts_indexp_insec_num_tbl )
  est2tex xt_indexp, replace dropall preserve ready p(brazrloc/tex/v4/`sampl'/trans) fancy digits(3) extracols(3) thousep
  * Table by period. L: xts_indexp_num_90_91, R: xts_indexp_num_96_97
  mat xt_indexp_per_tbl = xts_indexp_num_90_91_tbl , xts_indexp_num_96_97_tbl
  est2tex xt_indexp_per, replace dropall preserve ready p(brazrloc/tex/v4/`sampl'/trans) fancy digits(3) extracols(3) thousep
}

log close
