!* BRAZRLOC v4

program drop _all

* global root "c:/data"
global root "//acsnfs3.ucsd.edu/econgrad/muendler"
* global extdata "f:/data"
global extdata "//acsnfs3.ucsd.edu/econgrad/muendler"
* global srvdata "c:/data"
global srvdata "//acsnfs3.ucsd.edu/econgrad/muendler"

clear
set more off
set virtual on
* set trace on
set matsize 150
global maxiter 20

cd "$root"
adopath + "brazrloc/%stata/ado"
qui do "brazrloc/%stata/ado/%Read-tabl2tex.do"

capture mkdir "brazrloc/logs"
capture mkdir "brazrloc/data"
capture mkdir "brazrloc/estmat"
capture mkdir "brazrloc/estmat/v4"
capture mkdir "brazrloc/graphs"
capture mkdir "brazrloc/graphs/v4"
capture mkdir "brazrloc/tex"
capture mkdir "brazrloc/tex/v4"

global regdef "APD CEE LAC NAM ODV OIN WEU"
global reghomdef "APD CEE HOM LAC NAM ODV OIN WEU"

* set memory between 1G and 1.5G if preset to less than 1.5G
set mem 750m
qui query mem
if `r(memory)' < 1500000 {
  local maxmem 1500
  local minmem 1000
  local msz = `maxmem'
  while `msz' > `minmem' {
    local msz = `msz' - 10
    capture set mem `msz'm
    if _rc == 0 {
      query mem
      local msz `minmem'
      }
    }
  }


* 1. DATA PREPARATION
*--------------------

* do "brazrloc/%stata/%1prep-data/sector-list.do"
    /* PREPARE AGGREGATE SECTOR LIST BEYOND MANUFACTURING */
    /* INPUT:  "brazrloc/auxil/subsector-aggsector.csv"
               "rais/cnae/cnae2subsibge.dta"
               "rais/cnae/ibge.do" */
    /* OUTPUT: "brazrloc/auxil/subsibge2aggsec.dta"
               "brazrloc/auxil/aggsec.do" */
    /*   Logs: "brazrloc/logs/sector-list.log" */ 

* do "brazrloc/%stata/%1prep-data/metro-list.do"
    /* PREPARE MUNICIPALITY LIST WITH METROPOLITAN AREAS */
    /* INPUT:  "rais/auxil/origs/05 05 2005 base dados ajustada pib dos municpios 1999-2002.csv" */
    /* OUTPUT: "brazrloc/auxil/metro-list.dta"
               "brazrloc/auxil/metro-list.csv" */
    /*   Logs: "brazrloc/logs/metro-list.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-data-natl.do"
    /* PREPARE NATIONWIDE RAIS WORKER DATA */
    /* INPUT:  "rais/draws/natl/wid-draw-workers-natl.csv"
               "rais/cbo/cbostr2num.dta" */
    /*     DO: "rais/auxil/`lblfile'.do" (`lblfile' in sexo instr vinc desl nacional etaria adm estbl jurid)
               "rais/cnae/`lblfile'.do" (`lblfile' in ibge cnae_95)
               "rais/cbo/`lblfile'.do" (`lblfile' in cbogrp) */
    /* OUTPUT: "brazrloc/data/wid-draw-workers-natl.dta"
               "brazrloc/data/wid-draw-workers-natl-cnpj.dta" */
    /*   Logs: "brazrloc/logs/rais-data-natl.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-data-metro.do"
    /* PREPARE METROPOLITAN RAIS WORKER DATA */
    /* INPUT:  "rais/draws/metro/wid-draw-workers-metro-male.csv"
               "rais/cbo/cbostr2num.dta" */
    /*     DO: "rais/auxil/`lblfile'.do" (`lblfile' in sexo instr vinc desl nacional etaria adm estbl jurid)
               "rais/cnae/`lblfile'.do" (`lblfile' in ibge cnae_95)
               "rais/cbo/`lblfile'.do" (`lblfile' in cbogrp) */
    /* OUTPUT: "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/wid-draw-workers-metro-male-cnpj.dta" */
    /*   Logs: "brazrloc/logs/rais-data-metro-male.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-data-metro-subsample.do"
    /* RANDOM SUBSAMPLE OF METROPOLITAN RAIS WORKER DATA */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta" */
    /* OUTPUT: "brazrloc/data/wid-draw-workers-metro-male-subsample.dta" */
    /*   Logs: "brazrloc/logs/rais-data-metro-male-subsample.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-cnpj-list-natl.do"
    /* PREPARE RAIS PLANT DATA FOR ANNUAL PRESENCE LIST */
    /* INPUT:  "rais/base-cnpj/rais-catalog-cnpj.dta"
               "brazrloc/data/wid-draw-workers-natl-cnpj.csv" */
    /* OUTPUT: "brazrloc/data/rais-cnpj-list-natl.dta" */
    /*   Logs: "brazrloc/logs/rais-cnpj-list-natl.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-cnpj-list-metro.do"
    /* PREPARE RAIS PLANT DATA FOR ANNUAL PRESENCE LIST */
    /* INPUT:  "rais/base-cnpj/rais-catalog-cnpj-metro.dta"
               "brazrloc/data/wid-draw-workers-metro-male-cnpj.csv" */
    /* OUTPUT: "brazrloc/data/rais-cnpj-list-metro.dta" */
    /*   Logs: "brazrloc/logs/rais-cnpj-list-metro.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-cnpjradic-cnae95.do"
    /* FIRM-LEVEL CNAE SECTOR INFORMATION 1995 (FOR TABLES AND GRAPHS) */
    /* INPUT:  "rais/base-agg/cnpjradic/aggcnpj_`ext'.dta" (where `ext' in A through J)
               "brazrloc/data/rais-cnpj-list-natl.dta"
               "brazrloc/data/rais-cnpj-list-metro.dta" */
    /* OUTPUT: "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98.dta"
               "brazrloc/data/rais-cnpjradic-cnae95-metro-86-98.dta" */
    /*   Logs: "brazrloc/logs/rais-cnpjradic-cnae95.log" */ 

* do "brazrloc/%stata/%1prep-data/niv100-agg.do"
    /* PREPARE NIV50 SECTOR DATA BASED ON PIA AND RAIS INFORMATION (FOR TABLES AND GRAPHS) */
    /* INPUT:  "brazaux/Xpia/firms-86-98.dta" 
               "brazaux/pia/prodcoeff-brazprod.dta"
               "rais/cnae/niv100.do"
               "rais/cnae/niv50.do" */
    /* OUTPUT: "brazrloc/auxil/niv100-agg.dta"
               "brazrloc/auxil/niv50-agg.dta" */
    /*   Logs: "brazrloc/logs/niv100-agg.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-cnpj-data-metro.do"
    /* PREPARE METROPOLITAN PLANT DATA (FOR REGRESSIONS) */
    /* INPUT:  "rais/base-agg/cnpj/aggcnpj_`ext'.dta" (where `ext' in a b c d e f g h i j)
               "brazrloc/data/rais-cnpj-list-metro.dta" */
    /* OUTPUT: "brazrloc/data/rais-cnpj-data-metro.dta" */
    /*   Logs: "brazrloc/logs/rais-cnpj-data-metro.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-cnpj-data-natl.do"
    /* PREPARE NATIONAL PLANT DATA (FOR REGRESSIONS) */
    /* INPUT:  "rais/base-agg/cnpj/aggcnpj_`ext'.dta" (where `ext' in a b c d e f g h i j) 
               "brazrloc/data/rais-cnpj-list-natl.dta" */
    /* OUTPUT: "brazrloc/data/rais-cnpj-data-natl.dta" */
    /*   Logs: "brazrloc/logs/rais-cnpj-data-natl.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-cnpj-data-metro-nber.do"
    /* PREPARE METROPOLITAN PLANT DATA (FOR REGRESSIONS) */
    /* INPUT:  "rais/base-agg/cnpj/aggcnpj_`ext'.dta" (where `ext' in a b c d e f g h i j)
               "brazrloc/data/rais-cnpj-list-metro.dta" */
    /* OUTPUT: "brazrloc/data/rais-cnpj-data-metro-nber.dta" */
    /*   Logs: "brazrloc/logs/rais-cnpj-data-metro-nber.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-cnpj-data-natl-nber.do"
    /* PREPARE METROPOLITAN PLANT DATA (FOR REGRESSIONS) */
    /* INPUT:  "rais/base-agg/cnpj/aggcnpj_`ext'.dta" (where `ext' in a b c d e f g h i j) 
               "brazrloc/data/rais-cnpj-list-natl.dta" */
    /* OUTPUT: "brazrloc/data/rais-cnpj-data-natl-nber.dta" */
    /*   Logs: "brazrloc/logs/rais-cnpj-data-natl-nber.log" */ 

* do "brazrloc/%stata/%1prep-data/pia-data.do"
    /* PREPARE PIA DATA (FOR REGRESSIONS) */
    /* INPUT:  "brazaux/pia/random-3firm-rndmnr.dta"
               "brazaux/pia/random-3firm-firmlist-rndmnr.dta"
               "brazaux/pia/prodcoeff-brazprod.dta" */
    /* OUTPUT: "brazrloc/data/pia-data.dta" */
    /*   Logs: "brazrloc/logs/pia-data.log" */ 

* do "brazrloc/%stata/%1prep-data/sector-data.do"
    /* PREPARE AGGREGATE SECTOR DATA (FOR IV REGRESSIONS) */
    /* INPUT:  "rais/base-agg/cnae/aggsec.csv"
               "rais/base-agg/subsibge/aggsec.csv"
               "brazaux/auxil/seclvl.dta"
               "brazaux/auxil/seclvl-cnae.dta"
               "brazrloc/auxil/manual/niv50-subsibge-manual.csv" */
    /* OUTPUT: "brazrloc/auxil/sector-cnae-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/sector-subsibge-moredata.dta" */
    /*   Logs: "brazrloc/logs/sector-data.log" */ 

* do "brazrloc/%stata/%1prep-data/secex90-subsibge-expval.do"
    /* MAP SECEX FIRMS AND THEIR EXPORTS BY COUNTRY TO RAIS-SUBSIBGE SECTORS */
    /* INPUT:  "rais/base-agg/cnpjradic/aggcnpj_`file'.dta" (where `file' in a through j)
               "secex/data/csv/exp90.csv" */
    /* OUTPUT: "brazrloc/auxil/subsibge-country-exp90.dta" */
    /*   Logs: "brazrloc/logs/secex90-subsibge-expval.log" */ 

* do "brazrloc/%stata/%1prep-data/wtf-data.do"
    /* PREPARE WTF-NBER DATA (FOR IV REGRESSIONS) */
    /* INPUT:  "brazaux/conc/countries/country-table.dta"
               "brazaux/intl/nber/wtf_bilat.dta" */
    /* OUTPUT: "brazrloc/auxil/wtf-data.dta" */
    /*   Logs: "brazrloc/logs/wtf-data.log" */ 


* 2. TABLES AND GRAPHS
*---------------------

* do "brazrloc/%stata/%2tab-graph/empl-stats.do"
    /* CONVENTIONAL LABOR MARKET STATISTICS */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/wid-draw-workers-natl.dta" 
               "brazrloc/auxil/subsibge2aggsec.dta"
               "rais/base-agg/subsibge/aggsec.csv" 
               "rais/auxil/metro-pme.dta" */
    /* OUTPUT: none */
    /* Graphs: .
          TeX: "brazrloc/tex/v4/metromale-prime/laborstats/form_metromale_prime.tex"
               "brazrloc/tex/v4/metromale/laborstats/form_metromale.tex"
               "brazrloc/tex/v4/metromale/laborstats/form_metromale_sp.tex"
               "brazrloc/tex/v4/natl/laborstats/form_natl.tex"
               "brazrloc/tex/v4/natl/laborstats/form_natl_maleprime.tex"
               "brazrloc/tex/v4/natl/laborstats/form_sp.tex"
               "brazrloc/tex/v4/natl/laborstats/form_pop.tex" 
               "brazrloc/tex/v4/natl/laborstats/emplshare_pop.tex" */
    /*   Logs: "brazrloc/logs/empl-stats.log" */

* do "brazrloc/%stata/%2tab-graph/durations-natl.do"
    /* DURATIONS OF REALLOCATION FOR ANY WORKER IN BRAZIL */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta"
               "brazrloc/data/rais-cnpj-list.dta" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/natl/indnorloc`dur'm.eps" (where `dur' in 48 and 60)
               "brazrloc/graphs/v4/natl/indnorloc`dur'm-color.eps" (where `dur' in 48 and 60)
               "brazrloc/graphs/v4/natl/mo2rehir`dur'.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/natl/mo2rehir`dur'-color.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/natl/medmo2rehir`dur'.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/natl/medmo2rehir`dur'-color.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/natl/mo2rehir`dur'-contplants.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/natl/mo2rehir`dur'-contplants-color.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/natl/halflife`dur'.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/natl/halflife`dur'-color.eps" (where `dur' in 36 and 48)
          TeX: "brazrloc/tex/v4/natl/indnorloc`dur'm.tex" (where `dur' in 48 and 60)
               "brazrloc/tex/v4/natl/mo2rehr`dur'm.tex" (where `dur' in 36 and 48)
               "brazrloc/tex/v4/natl/mo2rehr`dur'm_cntplnts.tex" (where `dur' in 36 and 48)
               "brazrloc/tex/v4/natl/halflife`dur'm.tex" (where `dur' in 36 and 48) */
    /*   Logs: "brazrloc/logs/durations-natl.log" */

* do "brazrloc/%stata/%2tab-graph/durations-natl-maleprime.do"
    /* DURATIONS OF REALLOCATION FOR MALES AT PRIME AGE ANYWHERE IN BRAZIL */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta"
               "brazrloc/data/rais-cnpj-list.dta" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/natl-maleprime/indnorloc`dur'm.eps" (where `dur' in 12 48 60)
               "brazrloc/graphs/v4/natl-maleprime/indnorloc`dur'm-color.eps" (where `dur' in 12 48 60)
               "brazrloc/graphs/v4/natl-maleprime/mo2rehir`dur'.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl-maleprime/mo2rehir`dur'-color.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl-maleprime/medmo2rehir`dur'.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl-maleprime/medmo2rehir`dur'-color.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl-maleprime/mo2rehir`dur'-contplants.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl-maleprime/mo2rehir`dur'-contplants-color.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl-maleprime/halflife`dur'.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl-maleprime/halflife`dur'-color.eps" (where `dur' in 12 36 48)
          TeX: "brazrloc/tex/v4/natl-maleprime/indnorloc`dur'mbygrp.tex" (where `dur' in 12 48 60)
               "brazrloc/tex/v4/natl-maleprime/mo2rehr`dur'mbygrp.tex" (where `dur' in 12 36 48)
               "brazrloc/tex/v4/natl-maleprime/indnorloc`dur'm.tex" (where `dur' in 12 48 60)
               "brazrloc/tex/v4/natl-maleprime/mo2rehr`dur'm.tex" (where `dur' in 12 36 48)
               "brazrloc/tex/v4/natl-maleprime/mo2rehr`dur'm_cntplnts.tex" (where `dur' in 12 36 48)
               "brazrloc/tex/v4/natl-maleprime/halflife`dur'm.tex" (where `dur' in 12 36 48) */
    /*   Logs: "brazrloc/logs/durations-natl-maleprime.log" */

* do "brazrloc/%stata/%2tab-graph/durations-metromale.do"
    /* DURATIONS OF REALLOCATION FOR METROPOLITAN MALES */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/rais-cnpj-list.dta" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/metromale/indnorloc`dur'm.eps" (where `dur' in 48 and 60)
               "brazrloc/graphs/v4/metromale/indnorloc`dur'm-color.eps" (where `dur' in 48 and 60)
               "brazrloc/graphs/v4/metromale/mo2rehir`dur'm.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale/mo2rehir`dur'm-color.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale/medmo2rehir`dur'm.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale/medmo2rehir`dur'm-color.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale/mo2rehir`dur'm-contplants.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale/mo2rehir`dur'm-contplants-color.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale/halflife`dur'm.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale/halflife`dur'm-color.eps" (where `dur' in 36 and 48)
          TeX: "brazrloc/tex/v4/metromale/indnorloc`dur'm.tex" (where `dur' in 48 and 60)
               "brazrloc/tex/v4/metromale/mo2rehr`dur'm.tex" (where `dur' in 36 and 48)
               "brazrloc/tex/v4/metromale/mo2rehr`dur'm_cntplnts.tex" (where `dur' in 36 and 48)
               "brazrloc/tex/v4/metromale/halflife`dur'm.tex" (where `dur' in 36 and 48) */
    /*   Logs: "brazrloc/logs/durations-metromale.log" */

* do "brazrloc/%stata/%2tab-graph/durations-metromale-prime.do"
    /* DURATIONS OF REALLOCATION FOR METROPOLITAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/rais-cnpj-list.dta" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/metromale-prime/indnorloc`dur'm.eps" (where `dur' in 12, 24, 36, 48 and 60)
               "brazrloc/graphs/v4/metromale-prime/indnorloc`dur'm-color.eps" (where `dur' in 12, 24, 36, 48 and 60)
               "brazrloc/graphs/v4/metromale-prime/mo2rehir`dur'm.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale-prime/mo2rehir`dur'm-color.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale-prime/medmo2rehir`dur'm.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale-prime/medmo2rehir`dur'm-color.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale-prime/mo2rehir`dur'm-contplants.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale-prime/mo2rehir`dur'm-contplants-color.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale-prime/halflife`dur'm.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale-prime/halflife`dur'm-color.eps" (where `dur' in 36 and 48)
          TeX: "brazrloc/tex/v4/metromale-prime/indnorloc`dur'm.tex" (where `dur' in 12, 24, 36, 48 and 60)
               "brazrloc/tex/v4/metromale-prime/mo2rehr`dur'm.tex" (where `dur' in 36 and 48)
               "brazrloc/tex/v4/metromale-prime/mo2rehr`dur'm_cntplnts.tex" (where `dur' in 36 and 48)
               "brazrloc/tex/v4/metromale-prime/halflife`dur'm.tex" (where `dur' in 36 and 48) */
    /*   Logs: "brazrloc/logs/durations-metromale-prime.log" */

* do "brazrloc/%stata/%2tab-graph/labmkt-stats.do"
    /* LABOR MARKET EXPERIENCE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/wid-draw-workers-natl.dta" 
               "rais/auxil/metro-pme.dta" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/metromale-prime/laborstats/labmkttrns-86-98.eps"
               "brazrloc/graphs/v4/metromale-prime/laborstats/labmktexp-`period'.eps" (where `period' in 86-93, 90-97, 94-01)
               "brazrloc/graphs/v4/metromale/laborstats/labmktexp-`period'.eps" (where `period' in 86-93, 90-97, 94-01)
               "brazrloc/graphs/v4/metromale/laborstats/labmktexp-sp-`period'.eps" (where `period' in 86-93, 90-97)
               "brazrloc/graphs/v4/natl-maleprime/laborstats/labmkttrns-86-98.eps"
               "brazrloc/graphs/v4/natl-maleprime/laborstats/labmktexp-`period'.eps" (where `period' in 86-93, 90-97, 94-01)
               "brazrloc/graphs/v4/natl/laborstats/labmktexp-`period'.eps" (where `period' in 86-93, 90-97, 94-01)
               "brazrloc/graphs/v4/natl/laborstats/labmktexp-sp-`period'.eps" (where `period' in 86-93, 90-97)
          TeX: "brazrloc/tex/v4/metromale-prime/laborstats/labmkttrns_86_98.tex"
               "brazrloc/tex/v4/metromale-prime/laborstats/labmktexp_`period'.tex" (where `period' in 86_93, 90_97, 94_01)
               "brazrloc/tex/v4/metromale/laborstats/labmktexp_`period'.tex" (where `period' in 86_93, 90_97, 94_01) 
               "brazrloc/tex/v4/metromale/laborstats/labmktexp_sp_`period'.tex" (where `period' in 86_93, 90_97) 
               "brazrloc/tex/v4/natl-maleprime/laborstats/labmkttrns_86_98.tex"
               "brazrloc/tex/v4/natl-maleprime/laborstats/labmktexp_`period'.tex" (where `period' in 86_93, 90_97, 94_01)
               "brazrloc/tex/v4/natl/laborstats/labmktexp_`period'.tex" (where `period' in 86_93, 90_97, 94_01) 
               "brazrloc/tex/v4/natl/laborstats/labmktexp_sp_`period'.tex" (where `period' in 86_93, 90_97) */
    /*   Logs: "brazrloc/logs/labmkt-stats.log" */

* do "brazrloc/%stata/%2tab-graph/labocc-stats.do"
    /* OCCUPATIONAL EXPERIENCE (NATIONAL SAMPLE ONLY) */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/natl-maleprime/laborstats/labmkttrns-86-98.eps"
               "brazrloc/graphs/v4/natl-maleprime/laborstats/laboccexp-`period'.eps" (where `period' in 86-93, 90-97, 94-01)
               "brazrloc/graphs/v4/natl/laborstats/laboccexp-`period'.eps" (where `period' in 86-93, 90-97, 94-01)
               "brazrloc/graphs/v4/natl/laborstats/laboccexp-sp-`period'.eps" (where `period' in 86-93, 90-97)
          TeX: "brazrloc/tex/v4/natl-maleprime/laborstats/labmkttrns_86_98.tex"
               "brazrloc/tex/v4/natl-maleprime/laborstats/laboccexp_`period'.tex" (where `period' in 86_93, 90_97, 94_01)
               "brazrloc/tex/v4/natl/laborstats/laboccexp_`period'.tex" (where `period' in 86_93, 90_97, 94_01) 
               "brazrloc/tex/v4/natl/laborstats/laboccexp_sp_`period'.tex" (where `period' in 86_93, 90_97) */
    /*   Logs: "brazrloc/logs/labocc-stats.log" */

* do "brazrloc/%stata/%2tab-graph/transitions.do"
    /* SECTOR TRANSITIONS */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/wid-draw-workers-natl.dta" 
               "brazrloc/data/rais-cnpjradic-cnae95-metro-86-98.dta"
               "brazrloc/auxil/subsibge2aggsec.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "rais/auxil/metro-pme.dta" */
    /* OUTPUT: none */
    /* Graphs: .
          TeX: "brazrloc/tex/v4/`sampl'/trans/expsec_empl.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/expsec_empl_col.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xtcs_aggsec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xtcs_aggsec_num.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_aggsec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_aggsec_num.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_num.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_86_90.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_90_94.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_94_98.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_90_91.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_96_97.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_4yr.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_num.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_86_90.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_90_94.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_94_98.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_90_91.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_96_97.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_cnaesec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_cnaesec_num.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_cnaesec_90_91.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_cnaesec_96_97.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_cnaesec_unac.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_cnaesec_unac_num.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_cnaesec_unac_90_91.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_cnaesec_unac_96_97.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xtcs_indexp.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xtcs_indexp_num.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xtcs_indexp_insec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xtcs_indexp_num_insec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp_num.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp_num_90_91.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp_num_96_97.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp_insec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp_num_insec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp_manf.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp_manf_num.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp_manf_num_90_91.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp_manf_num_96_97.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               */
    /*   Logs: "brazrloc/logs/transitions.log" */

* do "brazrloc/%stata/%2tab-graph/braztfp-stats.do"
    /* HALTIWANGER AND OLLEY-PAKES REALLOCATION STATISTICS */
    /* INPUT:  "braztfp/decomp/haltiwanger-op-ipa2-output-notrend-fe-3x.dta"
               "braztfp/decomp/olleypakes-op-ipa2-output-notrend-fe-3x.dta"
               "braztfp/decomp/olleypakes-op-ipa2-output-notrend-fe-3x-1990.dta" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/tex/v4/tfp/haltiw_tfp.tex"
               "brazrloc/tex/v4/tfp/haltiw_lp.tex"
               "brazrloc/tex/v4/tfp/haltiw_all.tex"
               "brazrloc/tex/v4/tfp/haltiw_alt.tex"
               "brazrloc/tex/v4/tfp/ollpak.tex"
               "brazrloc/tex/v4/tfp/ollpak_alt.tex" */
    /*   Logs: "brazrloc/logs/tfp-stats.log" */

* do "brazrloc/%stata/%2tab-graph/tariff-data.do"
    /* TARIFF AND FIRM SURVIVAL GRAPHS (similar to rais-sp:firmempl.do) */
    /* INPUT:  "brazaux/auxil/tariff-data.dta"
               "brazrloc/tex/v4/natl-maleprime/duration/mo2rehr36m_tbl.dta"
               "brazrloc/tex/v4/natl-maleprime/duration/mo2rehr48m_tbl.dta" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/natl-maleprime/laborstats/tarfoutp-mo2rehir36-86-98.eps"
               "brazrloc/graphs/v4/natl-maleprime/laborstats/tarfoutp-mo2rehir48-86-98.eps"
               "brazrloc/graphs/v4/ext/tarfoutp-90-97.eps"
               "brazrloc/graphs/v4/ext/tarfintm-90-97.eps"
               "brazrloc/graphs/v4/ext/erp-90-97.eps"
               "brazrloc/graphs/v4/ext/herfsale-90-97.eps"
               "brazrloc/graphs/v4/ext/exits-90.eps" 
               "brazrloc/graphs/v4/ext/exits-97.eps" 
               "brazrloc/graphs/v4/ext/survival-90.eps" 
               "brazrloc/graphs/v4/ext/survival-97.eps" */
    /*   Logs: "brazrloc/logs/tariff-data.log" */

* do "brazrloc/%stata/%2tab-graph/compadv-data.do"
    /* COMPARATIVE ADVANTAGE AND FIRM SURVIVAL GRAPHS (similar to rais-sp:firmempl.do) */
    /* INPUT:  "brazaux/auxil/tariff-data.dta"
               "brazaux/auxil/comp-adv-niv50.dta" 
               "brazaux/intl/balassa-compadv-niv50.dta"
               "brazcomp/niv-cnae/niv50-en-systematic.tex"
               "brazrloc/auxil/niv50-agg.dta"
               "rais/cnae/niv50.do"
               "rais/cnae/niv100.do"
               "ca-us/gdf-ifs/ifs/brazil.csv" */
    /* OUTPUT: "brazrloc/estmat/v4/ext/`advtype'pol_`type'.dta" (where `advtype' in comp exp balc, `type' in b se e r)
               "brazrloc/estmat/v4/ext/`advtype'advreg_`type'.dta" (where `advtype' in comp exp balc, `type' in b se e r) */
    /* Graphs: "brazrloc/graphs/v4/ext/balcadv-res-chg-90-97.eps"
               "brazrloc/graphs/v4/ext/balcadv-chg-90-97.eps"
               "brazrloc/graphs/v4/ext/balcadv-res-chg-86-97.eps"
               "brazrloc/graphs/v4/ext/balcadv-chg-86-97.eps"
               "brazrloc/graphs/v4/ext/balcadv-res-chg-90-98.eps"
               "brazrloc/graphs/v4/ext/balcadv-chg-90-98.eps"
               "brazrloc/graphs/v4/ext/balcadv-res-chg-86-98.eps"
               "brazrloc/graphs/v4/ext/balcadv-chg-86-98.eps"
               "brazrloc/graphs/v4/ext/balcadv-expadv-fe-90.eps"
               "brazrloc/graphs/v4/ext/expadv-compadv-fe-90.eps"
               "brazrloc/graphs/v4/ext/balcadv-90.eps"
               "brazrloc/graphs/v4/ext/balcadv-turned-90.eps"
               "brazrloc/graphs/v4/ext/expadv-90.eps"
               "brazrloc/graphs/v4/ext/balcadv-90-97.eps"
               "brazrloc/graphs/v4/ext/expadv-90-97.eps"
               "brazrloc/graphs/v4/ext/balcadvfe-90-97.eps"
               "brazrloc/graphs/v4/ext/expadvfe-90-97.eps"
               "brazrloc/graphs/v4/ext/balcadv-tarif-86.eps"
               "brazrloc/graphs/v4/ext/balcadv-tarif-90.eps"
               "brazrloc/graphs/v4/ext/expadv-tarif-90.eps"
               "brazrloc/graphs/v4/ext/compadv-90-97.eps"
               "brazrloc/graphs/v4/ext/compadv-tarif-90.eps"
               "brazrloc/graphs/v4/ext/compadv-adj-90-97.eps"
               "brazrloc/graphs/v4/ext/compadvadj-expadvfe-90-97.eps"
               "brazrloc/graphs/v4/ext/tb-ca-91-02.eps"
          TeX: "brazrloc/tex/v4/ext/summ/niv5en.tex" 
               "brazrloc/tex/v4/ext/corr/corr_expadv_yrs.tex"
               "brazrloc/tex/v4/ext/corr/corr_balcadv_yrs.tex"
               "brazrloc/tex/v4/ext/corr/corr_adv.tex" */
    /*   Logs: "brazrloc/logs/compadv-data.log" */

* do "brazrloc/%stata/%2tab-graph/pme-stats.do"
    /* PME-BASED LABOR MARKET GRAPHS AND STATISTICS */
    /* INPUT:  "brazrloc/tex/v4/pme/tabelas.dta" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/pme/labmkttrns-86-98.eps"
               "brazrloc/graphs/v4/pme/emplshare-86-98.eps"
               "brazrloc/graphs/v4/pme/formemplshare-86-98.eps"
               "brazrloc/graphs/v4/pme/workstatus-86-98.eps"
               "brazrloc/graphs/v4/pme/workstatus-bar-86-98.eps"
               "brazrloc/graphs/v4/pme/workstatus-bar-nowithdr-86-98.eps"
               "brazrloc/graphs/v4/pme/formshare-86-98.eps"
               "brazrloc/graphs/v4/pme/formtrans-86-98.eps"
               "brazrloc/graphs/v4/pme/informtrans-86-98.eps"
          TeX: "brazrloc/tex/v4/pme/labmkttrns_86_98.tex"
               "brazrloc/tex/v4/pme/emplshare_86_98.tex"
               "brazrloc/tex/v4/pme/formemplshare_86_98.tex"
               "brazrloc/tex/v4/pme/formtrans_86_98.tex"
               "brazrloc/tex/v4/pme/informtrans_86_98.tex" */
    /*   Logs: "brazrloc/logs/pme-stats.log" */

* do "brazrloc/%stata/%2tab-graph/data-by-sec.do"
    /* TABLE OF MAIN REGRESSORS BY SECTOR */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/tex/v4/ext/summ/ibge.do"
          TeX: "brazrloc/tex/v4/ext/summ/subs_natlmaleprime.tex" */
    /*   Logs: "brazrloc/logs/data-by-sec.log" */ 

* do "brazrloc/%stata/%2tab-graph/katz-murphy.do"
    /* TABLES WITH KATZ-MURPHY (QJE 1992) DECOMPOSITIONS */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta" */
    /* OUTPUT: .
          TeX: "brazrloc/tex/v4/natl-maleprime/laborstats/katzmurp`span'.tex" (where `span' in "8689" "9098" "9901" "8698" "8601")
               "brazrloc/tex/v4/metromale-prime/laborstats/katzmurp`span'.tex" (where `span' in "8689" "9098" "9901" "8698" "8601") */
    /*   Logs: "brazrloc/logs/katz-murphy.log" */ 

* do "brazrloc/%stata/%2tab-graph/emplcomp-stats.do"
    /* WORKFORCE RECOMPOSITIONS */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta" */
    /* OUTPUT: .
       Grpahs: "brazrloc/graphs/v4/natl-maleprime/laborstats/occ-npis-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont") 
               "brazrloc/graphs/v4/natl-maleprime/laborstats/occ-effu-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont")
               "brazrloc/graphs/v4/natl-maleprime/laborstats/occ-stdeffu-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont") 
               "brazrloc/graphs/v4/natl-maleprime/laborstats/school-npis-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont") 
               "brazrloc/graphs/v4/natl-maleprime/laborstats/school-effu-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont")
               "brazrloc/graphs/v4/natl-maleprime/laborstats/school-stdeffu-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont")
               "brazrloc/graphs/v4/metromale-prime/laborstats/occ-npis-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont") 
               "brazrloc/graphs/v4/metromale-prime/laborstats/occ-effu-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont")
               "brazrloc/graphs/v4/metromale-prime/laborstats/occ-stdeffu-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont") 
               "brazrloc/graphs/v4/metromale-prime/laborstats/school-npis-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont") 
               "brazrloc/graphs/v4/metromale-prime/laborstats/school-effu-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont")
               "brazrloc/graphs/v4/metromale-prime/laborstats/school-stdeffu-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont") */
    /*   Logs: "brazrloc/logs/emplcomp-stats.log" */ 


* 3. REGRESSIONS
*---------------

* do "brazrloc/%stata/%3regress/separations-natl-maleprime-subsibge.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS FOR BRAZILIAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/separations-natl-maleprime-subsibge.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/subs_dspl_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_dspl_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/separations-natl-maleprime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/separations-metromale-prime-subsibge.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS FOR METROPOLITAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/wid-draw-workers-metro-male-subsample.dta"
               "brazrloc/data/rais-cnpj-data-metro.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/separations-metromale-prime-subsibge.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/metromale-prime/subs_dspl_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/metromale-prime/subs_dspl_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/separations-metromale-prime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/separations-natl-maleprime-cnae.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS FOR BRAZILIAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-cnae-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-cnae.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/separations-natl-maleprime-cnae.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/cnae_dspl_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/cnae_dspl_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/separations-natl-maleprime-cnae.log" */ 

* do "brazrloc/%stata/%3regress/separations-metromale-prime-cnae.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS FOR METROPOLITAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/wid-draw-workers-metro-male-subsample.dta"
               "brazrloc/data/rais-cnpj-data-metro.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-cnae-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-cnae.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/separations-metromale-prime-cnae.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/metromale-prime/cnae_dspl_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/metromale-prime/cnae_dspl_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/separations-metromale-prime-cnae.log" */ 

* do "brazrloc/%stata/%3regress/accessions-natl-maleprime-subsibge.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF ACCESSIONS FOR BRAZILIAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/accessions-natl-maleprime-subsibge.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/subs_hire_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_hire_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/accessions-natl-maleprime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/accessions-metromale-prime-subsibge.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF ACCESSIONS FOR METROPOLITAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/wid-draw-workers-metro-male-subsample.dta"
               "brazrloc/data/rais-cnpj-data-metro.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/accessions-metromale-prime-subsibge.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/metromale-prime/subs_hire_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/metromale-prime/subs_hire_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/accessions-metromale-prime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/accessions-natl-maleprime-cnae.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF ACCESSIONS FOR BRAZILIAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-cnae-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-cnae.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/accessions-natl-maleprime-cnae.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/cnae_hire_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/cnae_hire_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/accessions-natl-maleprime-cnae.log" */ 

* do "brazrloc/%stata/%3regress/accessions-metromale-prime-cnae.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF ACCESSIONS FOR METROPOLITAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/wid-draw-workers-metro-male-subsample.dta"
               "brazrloc/data/rais-cnpj-data-metro.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-cnae-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-cnae.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/accessions-metromale-prime-cnae.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/metromale-prime/cnae_hire_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/metromale-prime/cnae_hire_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/accessions-metromale-prime-cnae.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-aspme.do"
    /* CLOGIT REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/separations-natl-maleprime-subsibge.dta"
               "brazrloc/data/separations-metromale-prime-subsibge.dta"
               "brazrloc/data/accessions-natl-maleprime-subsibge.dta"
               "brazrloc/data/accessions-metromale-prime-subsibge.dta"
               "brazrloc/data/separations-natl-maleprime-cnae.dta"
               "brazrloc/data/separations-metromale-prime-cnae.dta"
               "brazrloc/data/accessions-natl-maleprime-cnae.dta"
               "brazrloc/data/accessions-metromale-prime-cnae.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/dsplhire_subs_aspme_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/dsplhire_cnae_aspme_`type'.dta" (where `type' in b se e) */
    /*   Logs: "brazrloc/logs/separations-accessions-aspme.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-paper-natl.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR MALES NATIONWIDE AT PRIME AGE */
    /* INPUT:  "brazrloc/data/separations-natl-maleprime-subsibge.dta"
               "brazrloc/data/accessions-natl-maleprime-subsibge.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/subsdspl_paper_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/subshire_paper_`type'.dta" (where `type' in b se e) */
    /*   Logs: "brazrloc/logs/separations-accessions-paper-natl.log" */ 

* do "brazrloc/%stata/%3regress/hazard-durations-natl-maleprime-subsibge.do"
    /* DURATIONS OF REALLOCATION FOR MALES AT PRIME AGE ANYWHERE IN BRAZIL */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta" 
               "brazrloc/data/rais-cnpj-list-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta" 
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/hazard-durations-natl-maleprime-subsibge.dta" (at first run)
       Graphs: "brazrloc/graphs/v4/natl-maleprime/hazard/kaplanmeier`year'.eps" (where `year' in 1986 1990)
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/aic_hzrd_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_hzrd_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_hzrd_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/hazard-durations-natl-maleprime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/hazard-nodyr-durations-natl-maleprime-subsibge.do"
    /* DURATIONS OF REALLOCATION FOR MALES AT PRIME AGE ANYWHERE IN BRAZIL */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta" 
               "brazrloc/data/rais-cnpj-list-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta" 
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/hazard-nodyr-durations-natl-maleprime-subsibge.dta" (at first run)
       Graphs: "brazrloc/graphs/v4/natl-maleprime/hazard-nodyr/kaplanmeier`year'-nodyr.eps" (where `year' in 1986 1990)
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/aic_hzrdnodyr_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_hzrdnodyr_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_hzrdnodyr_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/hazard-nodyr-durations-natl-maleprime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/ordered-durations-natl-maleprime-subsibge.do"
    /* DURATIONS OF REALLOCATION FOR MALES AT PRIME AGE ANYWHERE IN BRAZIL */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta" 
               "brazrloc/data/rais-cnpj-list-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta" 
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/ordered-durations-natl-maleprime-subsibge.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/subs_odur_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_odur_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/ordered-durations-natl-maleprime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/ordered-durations-metromale-prime-subsibge.do"
    /* DURATIONS OF REALLOCATION FOR METROPOLITAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta" 
               "brazrloc/data/rais-cnpj-list-metro.dta"
               "brazrloc/data/rais-cnpj-data-metro.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta" 
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/ordered-durations-metromale-prime-subsibge.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/metromale-prime/subs_odur_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/metromale prime/subs_odur_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/ordered-durations-metromale-prime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/ordered-durations-natl-maleprime-cnae.do"
    /* DURATIONS OF REALLOCATION FOR MALES AT PRIME AGE ANYWHERE IN BRAZIL */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta" 
               "brazrloc/data/rais-cnpj-list-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-cnae-data.dta"
               "brazrloc/auxil/wtf-data.dta" 
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-cnae.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/ordered-durations-natl-maleprime-cnae.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/cnae_odur_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/cnae_odur_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/ordered-durations-natl-maleprime-cnae.log" */ 

* do "brazrloc/%stata/%3regress/ordered-durations-metromale-prime-cnae.do"
    /* DURATIONS OF REALLOCATION FOR METROPOLITAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta" 
               "brazrloc/data/rais-cnpj-list-metro.dta"
               "brazrloc/data/rais-cnpj-data-metro.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-cnae-data.dta"
               "brazrloc/auxil/wtf-data.dta" 
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-cnae.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/ordered-durations-metromale-prime-cnae.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/metromale-prime/cnae_odur_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/metromale prime/cnae_odur_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/ordered-durations-metromale-prime-cnae.log" */ 

* do "brazrloc/%stata/%3regress/summary-stats-paper-natl.do"
    /* SUMMARY STATISTICS ON SEPARATION AND ACCESSION REGRESSIONS FOR PRIME-AGE MALES NATIONWIDE */
    /* INPUT:  "brazrloc/data/separations-natl-maleprime-subsibge.dta"
               "brazrloc/data/accessions-natl-maleprime-subsibge.dta" */
    /* OUTPUT: .
          TeX: "brazrloc/estmat/v4/reg/natl-maleprime/summ_dspl_`cond'.tex" (where `cond' in allsec balrnk1 balrnk3 balrnk5 indexp timevar) 
               "brazrloc/estmat/v4/reg/natl-maleprime/summ_hire_`cond'.tex" (where `cond' in allsec balrnk1 balrnk3 balrnk5 indexp timevar) 
               "brazrloc/estmat/v4/reg/natl-maleprime/summ_hzrd_`cond'.tex" (where `cond' in allsec balrnk1 balrnk3 balrnk5 indexp timevar) */
    /*   Logs: "brazrloc/logs/summary-stats-paper-natl.log" */ 

* do "brazrloc/%stata/%3regress/prediction-stats-paper-natl.do"
    /* SUMMARY STATISTICS ON SEPARATION AND ACCESSION REGRESSIONS FOR PRIME-AGE MALES NATIONWIDE */
    /* INPUT:  "brazrloc/data/separations-natl-maleprime-subsibge.dta"
               "brazrloc/data/accessions-natl-maleprime-subsibge.dta" 
               "brazrloc/estmat/v4/reg/natl-maleprime/subsdspl_paper_b.dta"
               "brazrloc/estmat/v4/reg/natl-maleprime/subshire_paper_b.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/tex/v4/gdp/subs`margin'`mat'_tbl.dta" (where `margin' in dspl hire and `mat' in _coef _tradvdif9290 _tradvdif9490 _tradvdif98900) */
    /*   Logs: "brazrloc/logs/prediction-stats-paper-natl.log" */ 

* do "brazrloc/%stata/%3regress/employment-natl-maleprime-subsibge.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS FOR BRAZILIAN MALES AT PRIME AGE NATIONWIDE */
    /* INPUT:  "brazrloc/data/rais-cnpj-data-natl-nber.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-moredata.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/employment-natl-maleprime-subsibge.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/subs_empl_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_empl_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/employment-natl-maleprime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/employment-metromale-prime-subsibge.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS FOR BRAZILIAN MALES AT PRIME AGE IN METROPOLITAN AREAS */
    /* INPUT:  "brazrloc/data/rais-cnpj-data-metro-nber.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-moredata.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/employment-metromale-prime-subsibge.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/metromale-prime/subs_empl_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/metromale-prime/subs_empl_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/employment-metromale-prime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/summary-stats-nber-natl.do"
    /* SUMMARY STATISTICS ON SEPARATION AND ACCESSION REGRESSIONS FOR PRIME-AGE MALES NATIONWIDE */
    /* INPUT:  "brazrloc/data/separations-natl-maleprime-subsibge.dta"
               "brazrloc/data/accessions-natl-maleprime-subsibge.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/subsdspl_paper_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/subshire_paper_`type'.dta" (where `type' in b se e) */
    /*   Logs: "brazrloc/logs/summary-stats-nber-natl.log" */ 

* do "brazrloc/%stata/%3regress/labprod-natl-maleprime-subsibge.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS FOR BRAZILIAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/employment-natl-maleprime-subsibge.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/subs_lnlp_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_lnlp_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/labprod-natl-maleprime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/labprod-metromale-prime-subsibge.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS FOR BRAZILIAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/employment-metromale-prime-subsibge.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/metromale-prime/subs_lnlp_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/metromale-prime/subs_lnlp_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/labprod-metromale-prime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/labprodlvl-natl-maleprime-subsibge.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS FOR BRAZILIAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/employment-natl-maleprime-subsibge.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/subs_lnlplvl_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_lnlplvl_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/labprodlvl-natl-maleprime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/labprodlvl-metromale-prime-subsibge.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS FOR BRAZILIAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/employment-metromale-prime-subsibge.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/metromale-prime/subs_lnlplvl_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/metromale-prime/subs_lnlplvl_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/labprodlvl-metromale-prime-subsibge.log" */ 


* 4. TABLES WITH STATISTICS AND RESULTS
*--------------------------------------

    do "brazrloc/%stata/%4tex/laborstat-tables.do"
    /* CONVENTIONAL LABOR MARKET STATISTICS */
    /* INPUT:  "brazrloc/tex/v4/metromale-prime/laborstats/form_metromale_prime_98_tbl.dta"
               "brazrloc/tex/v4/pme/formemplshare_86_98_tbl.dta"
               "brazrloc/tex/v4/metromale/laborstats/form_metromale_98_tbl.dta"
               "brazrloc/tex/v4/metromale/laborstats/form_metromale_sp_98_tbl.dta"
               "brazrloc/tex/v4/natl/laborstats/form_natl_98_tbl.dta"
               "brazrloc/tex/v4/natl/laborstats/form_natl_maleprime_98_tbl.dta"
               "brazrloc/tex/v4/natl/laborstats/form_sp_98_tbl.dta"
               "brazrloc/tex/v4/natl/laborstats/form_pop_98_tbl.dta" 
               "brazrloc/tex/v4/metromale-prime/trans/expsec_empl_col_tbl.dta"
               "brazrloc/tex/v4/natl-maleprime/trans/expsec_empl_col_tbl.dta"
               "brazrloc/tex/v4/natl/trans/expsec_empl_col_tbl.dta"
               "brazrloc/tex/v4/`sampl'/trans/`mat'_tbl.dta" (where `mat' in xtcs_indexp_num xtcs_indexp_num_insec xts_indexp_num xts_indexp_insec_num xts_indexp_num_90_91 xts_indexp_num_96_97 and `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/pme/tabelas.dta" */
    /* OUTPUT: none */
    /* Graphs: .
          TeX: "brazrloc/tex/v4/labor/form.tex"
               "brazrloc/tex/v4/labor/forminform.tex" 
               "brazrloc/tex/v4/labor/expsec.tex"
               "brazrloc/tex/v4/`sampl'/trans/xt_indexp.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl")
               "brazrloc/tex/v4/`sampl'/trans/xt_indexp_per.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") */
    /*   Logs: "brazrloc/logs/laborstat-tables.log" */

    do "brazrloc/%stata/%4tex/compadv-by-secagg.do"
    /* COMPARISONS OF COMPARATIVE ADVANTAGE BY SECTOR DEFINITION */
    /* INPUT:  "rais/base-agg/cnae/aggsec.csv"
               "rais/cnae/cnae-x-isic.dta"
               "rais/cnae/cnae2subsibge.dta"
               "brazaux/intl/balassa-compadv-cnae.dta"
               "brazaux/intl/balassa-compadv-niv50.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazcomp/filters/cnae2niv100.dta"
               "brazcomp/filters/cnae2niv100-app-agric.dta"
               "brazcomp/niv-cnae/cnae3d-en.csv"
               "brazcomp/niv-cnae/niv100.do"
               "brazrloc/auxil/manual/cnae2dgt-subsibge-manual.csv"
               "brazrloc/auxil/manual/niv50-subsibge-manual.csv" */
    /* OUTPUT: "brazrloc/auxil/cnae2dgt-subsibge-pseudoconc.csv"
               "brazrloc/auxil/niv50-subsibge-pseudoconc.csv"
               "brazrloc/auxil/cnae2dgt.do" */
    /* Graphs: .
          TeX: "brazrloc/tex/v4/ext/summ/subscnae.tex"
               "brazrloc/tex/v4/ext/summ/subsniv50.tex"
               "brazrloc/tex/v4/ext/summ/tabcnae.do"
               "brazrloc/tex/v4/ext/summ/tabniv50.do" */
    /*   Logs: "brazrloc/logs/compadv-by-secagg.log" */

    do "brazrloc/%stata/%4tex/compadv-tables.do"
    /* OUTPUT TABLES ON COMPARATIVE ADVANTAGE */
    /* INPUT:  "brazrloc/estmat/v4/ext/comppol_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/ext/compadvreg_`type'.dta" (where `type' in b se e)
               "brazrloc/estmat/v4/ext/exppol_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/ext/expadvreg_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/ext/balcpol_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/ext/balcadvreg_`type'.dta" (where `type' in b se e)
               "brazaux/intl/rigidity.dta"
               "brazrloc/%stata/rowlbl-brazrloc.tex" */
    /* OUTPUT: none
          TeX: "brazrloc/tex/v4/ext/reg/compadvreg.tex"
               "brazrloc/tex/v4/ext/reg/compadv.tex"
               "brazrloc/tex/v4/ext/reg/expadvreg.tex"
               "brazrloc/tex/v4/ext/reg/expadv.tex"
               "brazrloc/tex/v4/ext/reg/balcadvreg.tex"
               "brazrloc/tex/v4/ext/reg/balcadv.tex" 
               "brazrloc/tex/v4/labor/rigidity.tex" */
    /*   Logs: none */ 

    do "brazrloc/%stata/%4tex/laborstat-graphs.do"
    /* DISPLACEMENT, HIRING AND DURATION STATISTICS TO COMPLEMENT REGRESSIONS */
    /* INPUT:  "brazrloc/data/separations-natl-maleprime-subsibge.dta"
               "brazrloc/data/separations-metromale-prime-subsibge.dta"
               "brazrloc/data/accessions-natl-maleprime-subsibge.dta" 
               "brazrloc/data/accessions-metromale-prime-subsibge.dta"
               "brazrloc/data/ordered-durations-natl-maleprime-subsibge.dta"
               "brazrloc/data/ordered-durations-metromale-prime-subsibge.dta"
               "brazrloc/data/ordered-durations-natl-maleprime-cnae.dta"
               "brazrloc/data/ordered-durations-metromale-prime-cnae.dta"
               "brazrloc/%stata/rowlbl-brazrloc.tex" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/natl-maleprime/allsec-dsplhire.eps"
               "brazrloc/graphs/v4/natl-maleprime/manuf-dsplhire.eps"
               "brazrloc/graphs/v4/metromale-prime/allsec-dsplhire.eps"
               "brazrloc/graphs/v4/metromale-prime/manuf-dsplhire.eps"
               "brazrloc/graphs/v4/natl-maleprime/allsec-layoffquithire.eps"
               "brazrloc/graphs/v4/natl-maleprime/manuf-layoffquithire.eps"
               "brazrloc/graphs/v4/natl-maleprime/manuf-layoffquithire-98.eps"
               "brazrloc/graphs/v4/metromale-prime/allsec-layoffquithire.eps"
               "brazrloc/graphs/v4/metromale-prime/manuf-layoffquithire.eps"
          TeX: "brazrloc/tex/v4/labor/labstat_dspl.tex"
               "brazrloc/tex/v4/labor/labstat_hire.tex"
               "brazrloc/tex/v4/natl-maleprime/laborstats/rehircat_natl_subs.tex" 
               "brazrloc/tex/v4/metromale-prime/laborstats/rehircat_metro_subs.tex"
               "brazrloc/tex/v4/natl-maleprime/laborstats/rehircat_natl_cnae.tex"
               "brazrloc/tex/v4/metromale-prime/laborstats/rehircat_metro_cnae.tex"
               "brazrloc/tex/v4/labor/rehircat.tex" */
    /*   Logs: "brazrloc/logs/laborstat-graphs.log" */

    do "brazrloc/%stata/%4tex/gdp-impact.do"
    /* TABLES WITH GDP IMPACT MEASURES */
    /* INPUT:  "brazrloc/auxil/origs/pib.csv"
               "brazaux/auxil/minwage.dta"
               "brazrloc/tex/v4/natl-maleprime/duration/indnorloc12mbygrp_tbl.dta"
               "brazrloc/tex/v4/natl-maleprime/duration/mo2rehr12mbygrp_tbl.dta"
               "brazrloc/tex/v4/natl-maleprime/reg/paper_frmlnlp_tbl.dta" 
               "brazrloc/tex/v4/gdp/subs`margin'`mat'_tbl.dta" (where `margin' in dspl hire and `mat' in _coef _tradvars90 _tradvars92 _tradvars94 _tradvars98) 
               "brazrloc/tex/v4/gdp/gdpwage_tbl.dta"
               "brazrloc/tex/v4/pme/form2nonform_86_99_tbl.dta" 
               "brazrloc/tex/v4/pme/tabelas.dta" 
               "brazrloc/tex/v4/tfp/ollpak_alt_tbl.dta" */
    /* OUTPUT: none
          TeX: "brazrloc/tex/v4/pme/form2nonform_86_99.tex"
               "brazrloc/tex/v4/gdp/turnpred.tex"
               "brazrloc/tex/v4/gdp/turnpred_paper.tex"
               "brazrloc/tex/v4/gdp/rlocsucc_paper.tex"
               "brazrloc/tex/v4/gdp/gdpwage.tex" 
               "brazrloc/tex/v4/gdp/gdploss.tex"
               "brazrloc/tex/v4/gdp/gdp_turnov.tex" */
    /*   Logs: "brazrloc/logs/gdp-impact.log" */ 

    do "brazrloc/%stata/%4tex/reg-tab.do"
    /* OUTPUT TABLES FOR CLOGIT AND LOGIT REGRESSIONS */
    /* INPUT:  . */
    /* OUTPUT: none
          TeX: . */
    /*   Logs: none */ 
